[asterisk-commits] rmudgett: branch rmudgett/bridge_phase r388205 - /team/rmudgett/bridge_phase/...
SVN commits to the Asterisk project
asterisk-commits at lists.digium.com
Thu May 9 12:07:46 CDT 2013
Author: rmudgett
Date: Thu May 9 12:07:44 2013
New Revision: 388205
URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=388205
Log:
Tweak some comment and message text.
Modified:
team/rmudgett/bridge_phase/main/core_local.c
Modified: team/rmudgett/bridge_phase/main/core_local.c
URL: http://svnview.digium.com/svn/asterisk/team/rmudgett/bridge_phase/main/core_local.c?view=diff&rev=388205&r1=388204&r2=388205
==============================================================================
--- team/rmudgett/bridge_phase/main/core_local.c (original)
+++ team/rmudgett/bridge_phase/main/core_local.c Thu May 9 12:07:44 2013
@@ -554,11 +554,12 @@
return 0;
}
/* Do not let a masquerade cause a Local channel to be bridged to itself! */
bridge_owner = ast_channel_internal_bridge(p->owner);
bridge_chan = ast_channel_internal_bridge(p->chan);
if (bridge_owner && bridge_owner == bridge_chan) {
- ast_log(LOG_WARNING, "You can not bridge a Local channel to itself!\n");
+ ast_log(LOG_WARNING, "You can not bridge an unreal channel (%s) to itself!\n",
+ ast_channel_name(newchan));
ao2_unlock(p);
ast_queue_hangup(newchan);
return -1;
@@ -554,11 +554,12 @@
return 0;
}
- /* Do not let a masquerade cause a Local channel to be bridged to itself! */
+ /* Do not let a masquerade cause an unreal channel to be bridged to itself! */
bridge_owner = ast_channel_internal_bridge(p->owner);
bridge_chan = ast_channel_internal_bridge(p->chan);
More information about the asterisk-commits
mailing list